package edu.mermet.tp9;

import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import javax.swing.*;

import edu.mermet.tp9.fenetres.*;

/**
 * @author brunomermet
 */
public class Application extends JFrame {
    private JInternalFrame conversion;
    private JInternalFrame texte;
    private JInternalFrame diaporama;
    private JInternalFrame boutons;

    private Action actionAfficherConversion;
    private Action actionAfficherTexte;
    private Action actionAfficherDiaporama;
    private Action actionAfficherBoutons;

    public Application(String arg) {
        new Suggestion(arg);
        this.setContentPane(new JDesktopPane());
        setTitle("multi-fenêtres");
        Properties properties = new Properties();
        // ****** Barre de menu ******
        JMenuBar barre = new JMenuBar();

        // ------ menu Fichier ------
        JMenu menuFichier = new JMenu("Fichier");
        menuFichier.setMnemonic(KeyEvent.VK_F);
        JMenuItem quitter = new JMenuItem("Quitter");
        quitter.addActionListener(aev -> System.exit(0));
        quitter.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, InputEvent.CTRL_DOWN_MASK));
        menuFichier.add(quitter);
        barre.add(menuFichier);
        this.setJMenuBar(barre);

        // ------ menu Applications ------
        JMenu menuApplication = new JMenu("Applications");
        menuApplication.setMnemonic(KeyEvent.VK_A);
        actionAfficherConversion = new ActionAfficherConversion();
        JMenuItem itemConversion = new JMenuItem(actionAfficherConversion);
        menuApplication.add(itemConversion);
        actionAfficherTexte = new ActionAfficherTexte();
        JMenuItem itemTexte = new JMenuItem(actionAfficherTexte);
        menuApplication.add(itemTexte);
        actionAfficherDiaporama = new ActionAfficherDiaporama();
        JMenuItem itemDiaporama = new JMenuItem(actionAfficherDiaporama);
        menuApplication.add(itemDiaporama);
        actionAfficherBoutons = new ActionAfficherBoutons();
        JMenuItem itemBoutons = new JMenuItem(actionAfficherBoutons);
        menuApplication.add(itemBoutons);
        barre.add(menuApplication);

        // ------ menu Aide ------
        JMenu menuAide = new JMenu("Aide");
        Action actionAfficherHowto = new ActionAfficherHowTo();
        JMenuItem itemHowTo  = new JMenuItem(actionAfficherHowto);
        menuAide.add(itemHowTo);

        //itemHowTo.addItemListener(a -> SwingUtilities.invokeLater(HowTo::new));

        JMenuItem itemConfiguration = new JMenuItem("Configuration des menus");

        menuAide.add(itemConfiguration);
        barre.add(menuAide);

        itemConfiguration.addActionListener(a->{
           ConfigurationMenu config = new ConfigurationMenu(arg,properties);

            if(!config.getProperties().getProperty("conversion").equals("")) {
                if (config.getProperties().getProperty("conversion", "Caché").equals("Caché")) {
                    conversion.setVisible(false);
                } else if (config.getProperties().getProperty("conversion", "Affiché").equals("Affiché")) {
                    conversion.setVisible(true);
                }
            }
            if(!config.getProperties().getProperty("texte").equals("")){
                if(config.getProperties().getProperty("texte","Caché").equals("Caché")){
                    texte.setVisible(false);
                }else if(config.getProperties().getProperty("texte","Affiché").equals("Affiché")){
                    texte.setVisible(true);
                }
            }

            if(!config.getProperties().getProperty("diaporama").equals("")){
                if(config.getProperties().getProperty("diaporama","Caché").equals("Caché")){
                    diaporama.setVisible(false);
                }else if(config.getProperties().getProperty("diaporama","Affiché").equals("Affiché")){
                    diaporama.setVisible(true);
                }
            }
            if(!config.getProperties().getProperty("boutons").equals("")){
                if(config.getProperties().getProperty("boutons","Caché").equals("Caché")){
                    boutons.setVisible(false);
                }else if(config.getProperties().getProperty("boutons","Affiché").equals("Affiché")){
                    boutons.setVisible(true);
                }
            }
        });
        // ****** Fin barre de menu ******

        // ****** Création des fenêtres ******
        // ------ fenêtre conversion ------
        conversion = new FenetreConversion(actionAfficherConversion);
        this.add(conversion);
        // ------ fenêtre texte ------
        texte = new FenetreTexte(actionAfficherTexte);
        this.add(texte);
        // ------ fenêtre diaporama ------
        diaporama = new FenetreDiaporama(actionAfficherDiaporama);
        this.add(diaporama);
        // ------ fenêtre boutons ------
        boutons = new FenetreBoutons(this, actionAfficherBoutons);
        this.add(boutons);


        // ****** Fin création fenêtres ******
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(600, 300);
        this.setLocationRelativeTo(null);
        setVisible(true);
    }

    private class ActionAfficherBoutons extends AbstractAction {
        public ActionAfficherBoutons() {
            super("Boutons");
            putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_B, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY, KeyEvent.VK_B);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            boutons.setVisible(true);
            enableBoutons(false);
        }
    }

    private class ActionAfficherDiaporama extends AbstractAction {
        public ActionAfficherDiaporama() {
            super("Diaporama");
            putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_D, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY, KeyEvent.VK_D);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            diaporama.setVisible(true);
            enableDiaporama(false);
        }
    }

    private class ActionAfficherTexte extends AbstractAction {
        public ActionAfficherTexte() {
            super("Saisie de texte");
            putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_T, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY, KeyEvent.VK_T);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            texte.setVisible(true);
            enableTexte(false);
        }
    }

    public class ActionAfficherConversion extends AbstractAction {
        public ActionAfficherConversion() {
            super("Conversion Celsius/Farenheit");
            putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_C, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY, KeyEvent.VK_C);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            conversion.setVisible(true);
            enableConversion(false);
        }
    }

    public static class ActionAfficherHowTo extends AbstractAction {
        public ActionAfficherHowTo() {
            super("Comment faire ?");
            putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_H, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY, KeyEvent.VK_H);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            SwingUtilities.invokeLater(HowTo::new);
        }
    }

    public void enableConversion(boolean b) { actionAfficherConversion.setEnabled(b); }
    public void enableTexte     (boolean b) { actionAfficherTexte.setEnabled(b);      }
    public void enableDiaporama (boolean b) { actionAfficherDiaporama.setEnabled(b);  }
    public void enableBoutons   (boolean b) { actionAfficherBoutons.setEnabled(b);    }

    public Action getActionAfficherConversion() { return actionAfficherConversion; }
    public Action getActionAfficherTexte     () { return actionAfficherTexte;      }
    public Action getActionAfficherDiaporama () { return actionAfficherDiaporama;  }


    public static void main(String... args) {
        File file = new File(System.getProperty("user.home")+"/.ihm");
        boolean bool = file.mkdirs();
        if(bool){
            System.out.println("ok");
        }else{
            System.out.println("ko");
        }
        new Application((args.length >= 1)?args[0]:"");

    }
}
